@@ -24,8 +24,8 @@
 void pgp_gpgme_init (void);
 void smime_gpgme_init (void);
 
-char *pgp_gpgme_findkeys (ADDRESS *to, ADDRESS *cc, ADDRESS *bcc);
-char *smime_gpgme_findkeys (ADDRESS *to, ADDRESS *cc, ADDRESS *bcc);
+char *pgp_gpgme_findkeys (ADDRESS *adrlist, int oppenc_mode);
+char *smime_gpgme_findkeys (ADDRESS *adrlist, int oppenc_mode);
 
 BODY *pgp_gpgme_encrypt_message (BODY *a, char *keylist, int sign);
 BODY *smime_gpgme_build_smime_entity (BODY *a, char *keylist);
@@ -34,6 +34,7 @@ int pgp_gpgme_decrypt_mime (FILE *fpin, FILE **fpout, BODY *b, BODY **cur);
 int smime_gpgme_decrypt_mime (FILE *fpin, FILE **fpout, BODY *b, BODY **cur);
 
 int pgp_gpgme_check_traditional (FILE *fp, BODY *b, int tagged_only);
+void pgp_gpgme_invoke_import (const char* fname);
 
 int pgp_gpgme_application_handler (BODY *m, STATE *s);
 int smime_gpgme_application_handler (BODY *a, STATE *s);
@@ -52,6 +53,6 @@ int smime_gpgme_send_menu (HEADER *msg, int *redraw);
 
 int smime_gpgme_verify_sender (HEADER *h);
 
-void gpgme_set_sender (const char *sender);
+void mutt_gpgme_set_sender (const char *sender);
 
 #endif
