@@ -941,6 +941,12 @@ static int parse_unlist (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err
   return 0;
 }
 
+/* These two functions aren't sidebar-specific, but they are currently only
+ * used by the sidebar_whitelist/unsidebar_whitelist commands.
+ * Putting in an #ifdef to silence an unused function warning when the sidebar
+ * is disabled.
+ */
+#ifdef USE_SIDEBAR
 static int parse_path_list (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
 {
   char path[_POSIX_PATH_MAX];
@@ -980,6 +986,7 @@ static int parse_path_unlist (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER
 
   return 0;
 }
+#endif /* USE_SIDEBAR */
 
 static int parse_lists (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
 {
