@@ -84,6 +84,10 @@
 # define MAX(a,b) ((a) < (b) ? (b) : (a))
 # define MIN(a,b) ((a) < (b) ? (a) : (b))
 
+/* Use this with care.  If the compiler can't see the array
+ * definition, it obviously won't produce a correct result. */
+#define mutt_array_size(x)  (sizeof (x) / sizeof ((x)[0]))
+
 /* For mutt_format_string() justifications */
 /* Making left 0 and center -1 is of course completely nonsensical, but
  * it retains compatibility for any patches that call mutt_format_string.
@@ -160,8 +164,8 @@ void mutt_debug (FILE *, const char *, ...);
 #define S_BKG 126
 
 /* Flags for mutt_read_line() */
-#define M_CONT		(1<<0)		/* \-continuation */
-#define M_EOL		(1<<1)		/* don't strip \n/\r\n */
+#define MUTT_CONT		(1<<0)		/* \-continuation */
+#define MUTT_EOL		(1<<1)		/* don't strip \n/\r\n */
 
 /* The actual library functions. */
 
